==> openshift-model-operatorhub-5.10.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1/OperatorGroupStatusBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OperatorGroupStatusBuilder extends io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatusFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatus,io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatusBuilder>{
  public OperatorGroupStatusBuilder() {
    this(false);
  }
  public OperatorGroupStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new OperatorGroupStatus(), validationEnabled);
  }
  public OperatorGroupStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public OperatorGroupStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OperatorGroupStatus(), validationEnabled);
  }
  public OperatorGroupStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatusFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatus instance) {
    this(fluent, instance, false);
  }
  public OperatorGroupStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatusFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastUpdated(instance.getLastUpdated()); 
    fluent.withNamespaces(instance.getNamespaces()); 
    fluent.withServiceAccountRef(instance.getServiceAccountRef()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public OperatorGroupStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatus instance) {
    this(instance,false);
  }
  public OperatorGroupStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastUpdated(instance.getLastUpdated()); 
    this.withNamespaces(instance.getNamespaces()); 
    this.withServiceAccountRef(instance.getServiceAccountRef()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatus build() {
    OperatorGroupStatus buildable = new OperatorGroupStatus(fluent.getLastUpdated(),fluent.getNamespaces(),fluent.getServiceAccountRef());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OperatorGroupStatusBuilder that = (OperatorGroupStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-5.12.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1/OperatorGroupStatusBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OperatorGroupStatusBuilder extends io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatusFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatus,io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatusBuilder>{
  public OperatorGroupStatusBuilder() {
    this(false);
  }
  public OperatorGroupStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new OperatorGroupStatus(), validationEnabled);
  }
  public OperatorGroupStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public OperatorGroupStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OperatorGroupStatus(), validationEnabled);
  }
  public OperatorGroupStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatusFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatus instance) {
    this(fluent, instance, false);
  }
  public OperatorGroupStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatusFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withLastUpdated(instance.getLastUpdated()); 
    fluent.withNamespaces(instance.getNamespaces()); 
    fluent.withServiceAccountRef(instance.getServiceAccountRef()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public OperatorGroupStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatus instance) {
    this(instance,false);
  }
  public OperatorGroupStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withLastUpdated(instance.getLastUpdated()); 
    this.withNamespaces(instance.getNamespaces()); 
    this.withServiceAccountRef(instance.getServiceAccountRef()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupStatus build() {
    OperatorGroupStatus buildable = new OperatorGroupStatus(fluent.getConditions(),fluent.getLastUpdated(),fluent.getNamespaces(),fluent.getServiceAccountRef());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OperatorGroupStatusBuilder that = (OperatorGroupStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
